############################################################################
# Author: Henrik Bengtsson
#
# Usage:
#  library("aroma.tcga"); library("R.menu");
#  launchMenu(aroma.tcga, "testScripts/system/");
#
# Description:
# 1. Loads the "table" of existing data sets (from ll,(gbm|ov).Rex)
# 2. For each data set, if missing, creates an empty directory.
#
# This script should be called before try to download any TCGA data.
############################################################################
library("R.utils");
require("R.menu") || throw("Package not loaded: R.menu");

rootPath <- "tcgaData";
rootPath <- Arguments$getReadablePath(rootPath);


# Find the directory of this script being source():ed.
path <- getParent(names(findSourceTraceback())[1]);


# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Select tumor type
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
pattern <- "TCGA,DCC,dirs,(.*)[.]txt$";
pathnames <- list.files(path=path, pattern=pattern, full.names=TRUE);
tumorTypes <- gsub(pattern, "\\1", basename(pathnames));
if (interactive()) {
  ans <- textMenu(tumorTypes);
} else {
  ans <- 1;
}
tumorType <- tumorTypes[ans];
pathname <- pathnames[ans];


# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Get directory structure for the tumor type of interest
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
bfr <- readLines(pathname);
bfr <- bfr[-grep("^#", bfr)];
bfr <- bfr[-grep("^[ \t]*$", bfr)];

paths <- NULL;
path <- NULL;
lastIndent <- -1;
for (kk in seq(along=bfr)) {
  row <- bfr[kk];
  pattern <- "^([ ]*)(.*)";
  indent <- gsub(pattern, "\\1", row);
  indent <- nchar(indent);
  dir <- gsub(pattern, "\\2", row);
  dir <- gsub("/$", "", dir);
  delta <- (indent - lastIndent);
#  cat(sprintf("%+03d <%02d>%s\n", delta, indent, dir));
  # Sanity check
  if (delta > 1) {
    throw("File format error: Too large indentation");
  }

  if (delta <= 0) {
    path <- getParent(path, depth=-delta+1);
  }
  if (is.null(path)) {
    path <- dir;
  } else {
    path <- file.path(path, dir); 
  }
  paths <- c(paths, path);
  lastIndent <- indent;
} # for (kk ...)

paths <- file.path(rootPath, paths);
print(paths);


# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Create directory structure
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
dummy <- sapply(paths, mkdirs);


############################################################################
# HISTORY:
# 2010-04-05
# o Updated 'Usage'.
# 2009-10-20
# o Updated so that the tumor type can be selected interactively.
# 2009-10-15
# o Created.
############################################################################
